@@ -12,10 +12,10 @@
 
 from flask_babelex import gettext as _
 from invenio_records_resources.services import ConditionalLink, RecordLink
-from invenio_records_resources.services import \
-    RecordServiceConfig as RecordServiceConfigBase
-from invenio_records_resources.services import \
-    SearchOptions as SearchOptionsBase
+from invenio_records_resources.services import (
+    RecordServiceConfig as RecordServiceConfigBase,
+)
+from invenio_records_resources.services import SearchOptions as SearchOptionsBase
 from invenio_records_resources.services import pagination_links
 
 from .components import DraftMetadataComponent, PIDComponent
@@ -39,74 +39,74 @@ class SearchOptions(SearchOptionsBase):
 
     sort_options = {
         "bestmatch": dict(
-            title=_('Best match'),
-            fields=['_score'],  # ES defaults to desc on `_score` field
+            title=_("Best match"),
+            fields=["_score"],  # ES defaults to desc on `_score` field
         ),
         "newest": dict(
-            title=_('Newest'),
-            fields=['-created'],
+            title=_("Newest"),
+            fields=["-created"],
         ),
         "oldest": dict(
-            title=_('Oldest'),
-            fields=['created'],
+            title=_("Oldest"),
+            fields=["created"],
         ),
         "version": dict(
-            title=_('Version'),
-            fields=['-versions.index'],
+            title=_("Version"),
+            fields=["-versions.index"],
         ),
     }
 
     params_interpreters_cls = [
-        AllVersionsParam.factory('versions.is_latest')
+        AllVersionsParam.factory("versions.is_latest")
     ] + SearchOptionsBase.params_interpreters_cls
 
 
 class SearchDraftsOptions(SearchOptions):
     """Search options for drafts search."""
 
-    sort_default = 'bestmatch'
-    sort_default_no_query = 'updated-desc'
+    sort_default = "bestmatch"
+    sort_default_no_query = "updated-desc"
     sort_options = {
         "bestmatch": dict(
-            title=_('Best match'),
-            fields=['_score'],  # ES defaults to desc on `_score` field
+            title=_("Best match"),
+            fields=["_score"],  # ES defaults to desc on `_score` field
         ),
         "updated-desc": dict(
-            title=_('Recently updated'),
-            fields=['-updated'],
+            title=_("Recently updated"),
+            fields=["-updated"],
         ),
         "updated-asc": dict(
-            title=_('Least recently updated'),
-            fields=['updated'],
+            title=_("Least recently updated"),
+            fields=["updated"],
         ),
         "newest": dict(
-            title=_('Newest'),
-            fields=['-created'],
+            title=_("Newest"),
+            fields=["-created"],
         ),
         "oldest": dict(
-            title=_('Oldest'),
-            fields=['created'],
+            title=_("Oldest"),
+            fields=["created"],
         ),
         "version": dict(
-            title=_('Version'),
-            fields=['-versions.index'],
+            title=_("Version"),
+            fields=["-versions.index"],
         ),
     }
 
     params_interpreters_cls = [
-        AllVersionsParam.factory('versions.is_latest_draft')
+        AllVersionsParam.factory("versions.is_latest_draft")
     ] + SearchOptionsBase.params_interpreters_cls
 
 
 class SearchVersionsOptions(SearchOptions):
     """Search options for versions search."""
 
-    sort_default = 'version'
-    sort_default_no_query = 'version'
+    sort_default = "version"
+    sort_default_no_query = "version"
     sort_options = {
         "version": dict(
-            title=_('Version'),
-            fields=['-versions.index'],
+            title=_("Version"),
+            fields=["-versions.index"],
         ),
     }
     facets_options = dict(
@@ -155,8 +155,7 @@ class RecordServiceConfig(RecordServiceConfigBase):
         "draft": RecordLink("{+api}/records/{id}/draft", when=is_record),
         "record": RecordLink("{+api}/records/{id}", when=is_draft),
         "publish": RecordLink(
-            "{+api}/records/{id}/draft/actions/publish",
-            when=is_draft
+            "{+api}/records/{id}/draft/actions/publish", when=is_draft
         ),
         "versions": RecordLink("{+api}/records/{id}/versions"),
     }
@@ -165,5 +164,4 @@ class RecordServiceConfig(RecordServiceConfigBase):
 
     links_search_drafts = pagination_links("{+api}/user/records{?args*}")
 
-    links_search_versions = pagination_links(
-        "{+api}/records/{id}/versions{?args*}")
+    links_search_versions = pagination_links("{+api}/records/{id}/versions{?args*}")
